@@ -1,42 +1,52 @@
+import os
+from typing import List
+from enum import IntEnum
 
+import cv2 as cv
+import numpy as np
 from pydicom import dcmread
 from pydicom.dataset import Dataset
 from pydicom.sequence import Sequence
+
 from rt_utils.utils import SOPClassUID
-import os
 
-import numpy as np
-import cv2 as cv
-from enum import IntEnum
 
-"""
-File contains helper methods for loading / formatting DICOM images and contours
-"""
 def load_sorted_image_series(dicom_series_path: str):
-        series_data = load_CT_images_from_path(dicom_series_path)
+    """
+    File contains helper methods for loading / formatting DICOM images and contours
+    """
 
-        if len(series_data) == 0:
-            raise Exception("No CT Images found in input path")
+    series_data = load_dcm_images_from_path(dicom_series_path)
 
-        # Sort slices in ascending order
-        series_data.sort(key=lambda ds: ds.SliceLocation, reverse=False)
+    if len(series_data) == 0:
+        raise Exception("No DICOM Images found in input path")
 
-        return series_data
+    # Sort slices in ascending order
+    series_data.sort(key=lambda ds: ds.SliceLocation, reverse=False)
 
-def load_CT_images_from_path(dicom_series_path: str):
+    return series_data
+
+
+def load_dcm_images_from_path(dicom_series_path: str) -> List[Dataset]:
     series_data = []
     for root, _, files in os.walk(dicom_series_path):
         for file in files:
-            if file.endswith('.dcm'):
+            try:
                 ds = dcmread(os.path.join(root, file))
-                # Only add CT images
-                if ds.SOPClassUID == SOPClassUID.CT_IMAGE_STORAGE:
+                if hasattr(ds, 'pixel_array'):
                     series_data.append(ds)
+
+            except Exception:
+                # Not a valid DICOM file
+                continue
+
     return series_data
 
+
 def get_contours_coords(mask_slice: np.ndarray, series_slice: Dataset, use_pin_hole: bool):
     # Create pin hole mask if specified
-    if use_pin_hole: mask_slice = create_pin_hole_mask(mask_slice)
+    if use_pin_hole:
+        mask_slice = create_pin_hole_mask(mask_slice)
 
     # Get contours from mask
     contours, _ = find_mask_contours(mask_slice)
@@ -52,6 +62,7 @@ def get_contours_coords(mask_slice: np.ndarray, series_slice: Dataset, use_pin_h
 
     return formatted_contours 
 
+
 def find_mask_contours(mask):
     contours, hierarchy = cv.findContours(mask.astype(np.uint8), cv.RETR_TREE, cv.CHAIN_APPROX_SIMPLE)
     # Format extra array out of data
@@ -62,11 +73,13 @@ def find_mask_contours(mask):
     return contours, hierarchy
 
 
-"""
-Creates masks with pin holes added to contour regions with holes.
-This is done so that a given region can be represented by a single contour.
-"""
+
 def create_pin_hole_mask(mask):
+    """
+    Creates masks with pin holes added to contour regions with holes.
+    This is done so that a given region can be represented by a single contour.
+    """
+
     contours, hierarchy = find_mask_contours(mask)
     pin_hole_mask = mask.copy()
 
@@ -82,6 +95,7 @@ def create_pin_hole_mask(mask):
         pin_hole_mask = draw_line_upwards_from_point(pin_hole_mask, line_start, fill_value=0)
     return pin_hole_mask
 
+
 def draw_line_upwards_from_point(mask: np.ndarray, start, fill_value: int) -> np.ndarray:
     line_width = 2
     end = (start[0], start[1] - 1)
@@ -98,8 +112,8 @@ def draw_line_upwards_from_point(mask: np.ndarray, start, fill_value: int) -> np
 
 def validate_contours(contours: list):
     if len(contours) == 0:
-        raise Exception ("Unable to find contour in non empty mask, please check your mask formatting"
-    ) 
+        raise Exception("Unable to find contour in non empty mask, please check your mask formatting")
+
 
 def translate_contour_to_data_coordinants(contour, series_slice: Dataset):
     offset = series_slice.ImagePositionPatient
@@ -108,6 +122,7 @@ def translate_contour_to_data_coordinants(contour, series_slice: Dataset):
     contour[:, 1] = (contour[:, 1]) * spacing[1] + offset[1]
     return contour
 
+
 def translate_contour_to_pixel_coordinants(contour, series_slice: Dataset):
     offset = series_slice.ImagePositionPatient
     spacing = series_slice.PixelSpacing
@@ -116,6 +131,7 @@ def translate_contour_to_pixel_coordinants(contour, series_slice: Dataset):
 
     return contour
 
+
 def format_contour_for_dicom(contour, series_slice: Dataset):
     # DICOM uses a 1d array of x, y, z coords
     z_indicies = np.ones((contour.shape[0], 1)) * series_slice.SliceLocation
@@ -124,6 +140,7 @@ def format_contour_for_dicom(contour, series_slice: Dataset):
     contour = contour.tolist()
     return contour
 
+
 def create_series_mask_from_contour_sequence(series_data, contour_sequence: Sequence):
     mask = create_empty_series_mask(series_data)
 
@@ -134,6 +151,7 @@ def create_series_mask_from_contour_sequence(series_data, contour_sequence: Sequ
             mask[:, :, i] = get_slice_mask_from_slice_contour_data(series_slice, slice_contour_data)
     return mask
 
+
 def get_slice_contour_data(series_slice: Dataset, contour_sequence: Sequence):
     slice_contour_data = []
     
@@ -145,6 +163,7 @@ def get_slice_contour_data(series_slice: Dataset, contour_sequence: Sequence):
 
     return slice_contour_data
 
+
 def get_slice_mask_from_slice_contour_data(series_slice: Dataset, slice_contour_data):
     slice_mask = create_empty_slice_mask(series_slice)
     for contour_coords in slice_contour_data:    
@@ -153,6 +172,7 @@ def get_slice_mask_from_slice_contour_data(series_slice: Dataset, slice_contour_
         slice_mask[fill_mask == 1] = np.invert(slice_mask[fill_mask == 1])
     return slice_mask
 
+
 def get_contour_fill_mask(series_slice: Dataset, contour_coords):
     # Format data
     reshaped_contour_data = np.reshape(contour_coords, [len(contour_coords) // 3, 3]).astype(int)
@@ -164,22 +184,26 @@ def get_contour_fill_mask(series_slice: Dataset, contour_coords):
     cv.fillPoly(img=fill_mask, pts=polygon, color=1)
     return fill_mask
 
+
 def create_empty_series_mask(series_data):
     ref_dicom_image = series_data[0]
     mask_dims = (int(ref_dicom_image.Columns), int(ref_dicom_image.Rows), len(series_data))
     mask = np.zeros(mask_dims).astype(bool)
     return mask
 
+
 def create_empty_slice_mask(series_slice):
     mask_dims = (int(series_slice.Columns), int(series_slice.Rows))
     mask = np.zeros(mask_dims).astype(bool)
     return mask
 
-"""
-Enum class for what the positions in the OpenCV hierarcy array mean
-"""
+
 class Hierarchy(IntEnum):
+    """
+    Enum class for what the positions in the OpenCV hierarchy array mean
+    """
+
     next_node = 0
     previous_node = 1
     first_child = 2
-    parent_node = 3
\ No newline at end of file
+    parent_node = 3
